@@ -53,6 +53,9 @@ INTERNALERROR_GETACCOUNTSTATUSFAILED = 'InternalError.GetAccountStatusFailed'
 # 参数错误。
 INVALIDPARAMETER = 'InvalidParameter'
 
+# 快照策略未找到。
+INVALIDPARAMETER_AUTOPOLICYNOTFOUND = 'InvalidParameter.AutoPolicyNotFound'
+
 # 用于保证请求幂等性的字符串长度超过限制（不能超过64字节）。
 INVALIDPARAMETERVALUE_CLIENTTOKENLIMITEXCEEDED = 'InvalidParameterValue.ClientTokenLimitExceeded'
 
@@ -134,6 +137,9 @@ INVALIDPARAMETERVALUE_INVALIDSUBNETID = 'InvalidParameterValue.InvalidSubnetId'
 # 标签键不能为空。
 INVALIDPARAMETERVALUE_INVALIDTAGKEY = 'InvalidParameterValue.InvalidTagKey'
 
+# 无效的容量值。
+INVALIDPARAMETERVALUE_INVALIDTURBOCAPACITY = 'InvalidParameterValue.InvalidTurboCapacity'
+
 # 用户权限设置错误。
 INVALIDPARAMETERVALUE_INVALIDUSERPERMISSION = 'InvalidParameterValue.InvalidUserPermission'
 
